@@ -102,7 +102,7 @@ sub URI {
 
 =head2 $link->url_abs()
 
-Returns a L<URI::URL> object for the absolute form of the string.
+Returns a URI::URL object for the absolute form of the string.
 
 =cut
 
@@ -112,26 +112,11 @@ sub url_abs {
     return $self->URI->abs;
 }
 
-=head1 SEE ALSO
+=head1 COPYRIGHT
 
-L<WWW::Mechanize> and L<WWW::Mechanize::Image>
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2004-2010 Andy Lester.
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of either:
-
-=over 4
-
-=item * the GNU General Public License as published by the Free
-Software Foundation; either version 1, or (at your option) any later
-version, or
-
-=item * the Artistic License version 2.0.
-
-=back
+Copyright (c) 2004-2007 Andy Lester. All rights reserved. This program is
+free software; you can redistribute it and/or modify it under the same
+terms as Perl itself.
 
 =cut
 
