@@ -1,6 +1,7 @@
 package LocalServer;
 
 # start a fake webserver, fork, and connect to ourselves
+use warnings;
 use strict;
 use Test::More;
 use LWP::Simple;
@@ -42,8 +43,8 @@ sub spawn {
   my $self = { %args };
   bless $self,$class;
 
-  local $ENV{TEST_HTTP_VERBOSE} = 1
-    if (delete $args{debug});
+  local $ENV{TEST_HTTP_VERBOSE};
+  $ENV{TEST_HTTP_VERBOSE} = 1 if delete $args{debug};
 
   $self->{delete} = [];
   if (my $html = delete $args{html}) {
@@ -78,7 +79,7 @@ sub spawn {
   $self->{_fh} = $server;
 
   my $lhurl = URI::URL->new( $url );
-  $lhurl->host( "localhost" );
+  $lhurl->host( 'localhost' );
   $self->{_server_url} = $lhurl;
 
   diag "Started $lhurl";
@@ -95,7 +96,7 @@ if you need to compare results from two runs.
 =cut
 
 sub port {
-  carp __PACKAGE__ . "::port called without a server" unless $_[0]->{_server_url};
+  carp __PACKAGE__ . '::port called without a server' unless $_[0]->{_server_url};
   $_[0]->{_server_url}->port
 };
 
@@ -115,6 +116,20 @@ sub url {
   return $url->as_string;
 };
 
+=head2 C<< $server->creds_required >>
+
+This returns a URL for a page that requires HTTP Basic-Auth.  The
+content returned is invariant and irrelevant; this method is for
+testing credential-passing code.  The username is 'luser' and the
+password is 'fnord'.  When these credentials are passed, the returned
+status will be 200, otherwise it will be 401.
+
+=cut
+
+sub creds_required {
+  return $_[0]->{_server_url} . 'creds_required';
+}
+
 =head2 C<< $server->stop >>
 
 This stops the server process by requesting a special
@@ -123,7 +138,7 @@ url.
 =cut
 
 sub stop {
-  get( $_[0]->{_server_url} . "quit_server" );
+  get( $_[0]->{_server_url} . 'quit_server' );
   undef $_[0]->{_server_url}
 };
 
@@ -141,17 +156,22 @@ sub get_output {
   $self->stop;
   local $/;
   local *LOG;
-  open LOG, "<", $self->{logfile}
+  open LOG, '<', $self->{logfile}
     or die "Couldn't retrieve logfile";
-  join "", <LOG>;
-};
+  return join "", <LOG>;
+}
 
 sub DESTROY {
-  $_[0]->stop if $_[0]->{_server_url};
-  for my $file (@{$_[0]->{delete}}) {
-    unlink $file or warn "Couldn't remove tempfile $file : $!\n";
-  };
-};
+    my $self = shift;
+    $self->stop if $self->{_server_url};
+    if ( $self->{_fh} ) {
+        close $self->{_fh};
+        delete $self->{_fh};
+    }
+    for my $file ( @{$self->{delete}} ) {
+        unlink $file or warn "Couldn't remove tempfile $file : $!\n";
+    }
+}
 
 =head1 EXPORT
 
